@@ -375,30 +375,30 @@ fn test_run() {
     }
 }
 
-#[cfg(test)]
-fn print_wasmer_root_to_stdout(config: &Config) {
-    println!("print_wasmer_root_to_stdout");
+// #[cfg(test)]
+// fn print_wasmer_root_to_stdout(config: &Config) {
+//     println!("print_wasmer_root_to_stdout");
 
-    use walkdir::WalkDir;
+//     use walkdir::WalkDir;
 
-    for entry in WalkDir::new(&config.wasmer_dir)
-        .into_iter()
-        .filter_map(Result::ok)
-    {
-        let f_name = String::from(entry.path().canonicalize().unwrap().to_string_lossy());
-        println!("{f_name}");
-    }
+//     for entry in WalkDir::new(&config.wasmer_dir)
+//         .into_iter()
+//         .filter_map(Result::ok)
+//     {
+//         let f_name = String::from(entry.path().canonicalize().unwrap().to_string_lossy());
+//         println!("{f_name}");
+//     }
 
-    for entry in WalkDir::new(&config.root_dir)
-        .into_iter()
-        .filter_map(Result::ok)
-    {
-        let f_name = String::from(entry.path().canonicalize().unwrap().to_string_lossy());
-        println!("{f_name}");
-    }
+//     for entry in WalkDir::new(&config.root_dir)
+//         .into_iter()
+//         .filter_map(Result::ok)
+//     {
+//         let f_name = String::from(entry.path().canonicalize().unwrap().to_string_lossy());
+//         println!("{f_name}");
+//     }
 
-    println!("printed");
-}
+//     println!("printed");
+// }
 
 #[cfg(test)]
 fn fixup_symlinks(
