@@ -1,13 +1,14 @@
 use crate::commands::AsyncCliCommand;
 
+pub mod credentials;
 pub mod list;
-pub mod s3_credentials;
 
 /// App volume management.
 #[derive(Debug, clap::Parser)]
 pub enum CmdAppVolumes {
-    S3Credentials(s3_credentials::CmdAppS3Credentials),
+    Credentials(credentials::CmdAppVolumesCredentials),
     List(list::CmdAppVolumesList),
+    RotateSecrets(credentials::rotate_secrets::CmdAppVolumesRotateSecrets),
 }
 
 #[async_trait::async_trait]
@@ -16,7 +17,11 @@ impl AsyncCliCommand for CmdAppVolumes {
 
     async fn run_async(self) -> Result<Self::Output, anyhow::Error> {
         match self {
-            Self::S3Credentials(c) => {
+            Self::Credentials(c) => {
+                c.run_async().await?;
+                Ok(())
+            }
+            Self::RotateSecrets(c) => {
                 c.run_async().await?;
                 Ok(())
             }
