@@ -1,6 +1,7 @@
 //! The commands available in the Wasmer binary.
 mod add;
 mod app;
+mod auth;
 #[cfg(target_os = "linux")]
 mod binfmt;
 mod cache;
@@ -22,7 +23,6 @@ mod init;
 mod inspect;
 #[cfg(feature = "journal")]
 mod journal;
-mod login;
 pub(crate) mod namespace;
 mod package;
 mod run;
@@ -31,7 +31,6 @@ pub mod ssh;
 mod validate;
 #[cfg(feature = "wast")]
 mod wast;
-mod whoami;
 use std::env::args;
 use tokio::task::JoinHandle;
 
@@ -50,8 +49,8 @@ pub use {create_obj::*, gen_c_header::*};
 #[cfg(feature = "journal")]
 pub use self::journal::*;
 pub use self::{
-    add::*, cache::*, config::*, container::*, init::*, inspect::*, login::*, package::*,
-    publish::*, run::Run, self_update::*, validate::*, whoami::*,
+    add::*, auth::*, cache::*, config::*, container::*, init::*, inspect::*, package::*,
+    publish::*, run::Run, self_update::*, validate::*,
 };
 use crate::error::PrettyError;
 
@@ -185,7 +184,8 @@ impl WasmerCmd {
             Some(Cmd::Config(config)) => config.execute(),
             Some(Cmd::Inspect(inspect)) => inspect.execute(),
             Some(Cmd::Init(init)) => init.execute(),
-            Some(Cmd::Login(login)) => login.execute(),
+            Some(Cmd::Login(login)) => login.run(),
+            Some(Cmd::Auth(auth)) => auth.run(),
             Some(Cmd::Publish(publish)) => publish.run().map(|_| ()),
             Some(Cmd::Package(cmd)) => match cmd {
                 Package::Download(cmd) => cmd.execute(),
@@ -193,6 +193,7 @@ impl WasmerCmd {
                 Package::Tag(cmd) => cmd.run(),
                 Package::Push(cmd) => cmd.run(),
                 Package::Publish(cmd) => cmd.run().map(|_| ()),
+                Package::Unpack(cmd) => cmd.execute(),
             },
             Some(Cmd::Container(cmd)) => match cmd {
                 crate::commands::Container::Unpack(cmd) => cmd.execute(),
@@ -206,7 +207,7 @@ impl WasmerCmd {
             Some(Cmd::Wast(wast)) => wast.execute(),
             #[cfg(target_os = "linux")]
             Some(Cmd::Binfmt(binfmt)) => binfmt.execute(),
-            Some(Cmd::Whoami(whoami)) => whoami.execute(),
+            Some(Cmd::Whoami(whoami)) => whoami.run(),
             Some(Cmd::Add(install)) => install.execute(),
 
             // Deploy commands.
@@ -289,6 +290,9 @@ enum Cmd {
     /// Login into a wasmer.io-like registry
     Login(Login),
 
+    #[clap(subcommand)]
+    Auth(CmdAuth),
+
     /// Publish a package to a registry [alias: package publish]
     #[clap(name = "publish")]
     Publish(crate::commands::package::publish::PackagePublish),
