@@ -155,6 +155,15 @@ impl FileSystem for WebcVolumeFileSystem {
     fn new_open_options(&self) -> crate::OpenOptions {
         crate::OpenOptions::new(self)
     }
+
+    fn mount(
+        &self,
+        _name: String,
+        _path: &Path,
+        _fs: Box<dyn FileSystem + Send + Sync>,
+    ) -> Result<(), FsError> {
+        Err(FsError::Unsupported)
+    }
 }
 
 impl FileOpener for WebcVolumeFileSystem {
