@@ -84,7 +84,7 @@ cfg_if::cfg_if! {
         pub type TrapHandlerFn<'a> = dyn Fn(libc::c_int, *const libc::siginfo_t, *const libc::c_void) -> bool + Send + Sync + 'a;
     } else if #[cfg(target_os = "windows")] {
         /// Function which may handle custom signals while processing traps.
-        pub type TrapHandlerFn<'a> = dyn Fn(winapi::um::winnt::PEXCEPTION_POINTERS) -> bool + Send + Sync + 'a;
+        pub type TrapHandlerFn<'a> = dyn Fn(*mut windows_sys::Win32::System::Diagnostics::Debug::EXCEPTION_POINTERS) -> bool + Send + Sync + 'a;
     }
 }
 
@@ -465,10 +465,20 @@ cfg_if::cfg_if! {
             };
         }
     } else if #[cfg(target_os = "windows")] {
-        use winapi::um::errhandlingapi::*;
-        use winapi::um::winnt::*;
-        use winapi::um::minwinbase::*;
-        use winapi::vc::excpt::*;
+        use windows_sys::Win32::System::Diagnostics::Debug::{
+            AddVectoredExceptionHandler,
+            CONTEXT,
+            EXCEPTION_CONTINUE_EXECUTION,
+            EXCEPTION_CONTINUE_SEARCH,
+            EXCEPTION_POINTERS,
+        };
+        use windows_sys::Win32::Foundation::{
+            EXCEPTION_ACCESS_VIOLATION,
+            EXCEPTION_ILLEGAL_INSTRUCTION,
+            EXCEPTION_INT_DIVIDE_BY_ZERO,
+            EXCEPTION_INT_OVERFLOW,
+            EXCEPTION_STACK_OVERFLOW,
+        };
 
         unsafe fn platform_init() {
             // our trap handler needs to go first, so that we can recover from
@@ -480,8 +490,8 @@ cfg_if::cfg_if! {
         }
 
         unsafe extern "system" fn exception_handler(
-            exception_info: PEXCEPTION_POINTERS
-        ) -> LONG {
+            exception_info: *mut EXCEPTION_POINTERS
+        ) -> i32 {
             // Check the kind of exception, since we only handle a subset within
             // wasm code. If anything else happens we want to defer to whatever
             // the rest of the system wants to do for this exception.
@@ -993,7 +1003,7 @@ pub fn lazy_per_thread_init() -> Result<(), Trap> {
     // We need additional space on the stack to handle stack overflow
     // exceptions. Rust's initialization code sets this to 0x5000 but this
     // seems to be insufficient in practice.
-    use winapi::um::processthreadsapi::SetThreadStackGuarantee;
+    use windows_sys::Win32::System::Threading::SetThreadStackGuarantee;
     if unsafe { SetThreadStackGuarantee(&mut 0x10000) } == 0 {
         panic!("failed to set thread stack guarantee");
     }
